==> bodo-2022.5.2-cp38-cp38-macosx_10_15_x86_64.whl: bodo/libs/logging_ext.py <==
"""
JIT support for Python's logging module
"""
import logging
import numba
from numba.core import types
from numba.core.imputils import lower_constant
from numba.core.typing.templates import bound_function
from numba.core.typing.templates import AttributeTemplate, infer_getattr, signature
from numba.extending import NativeValue, box, models, overload_attribute, overload_method, register_model, typeof_impl, unbox
from bodo.utils.typing import create_unsupported_overload, gen_objmode_attr_overload


class LoggingLoggerType(types.Type):

    def __init__(self, is_root=False):
        self.is_root = is_root
        super(LoggingLoggerType, self).__init__(name=
            f'LoggingLoggerType(is_root={is_root})')


@typeof_impl.register(logging.RootLogger)
@typeof_impl.register(logging.Logger)
def typeof_logging(val, c):
    if isinstance(val, logging.RootLogger):
        return LoggingLoggerType(is_root=True)
    else:
        return LoggingLoggerType(is_root=False)


register_model(LoggingLoggerType)(models.OpaqueModel)


@box(LoggingLoggerType)
def box_logging_logger(typ, val, c):
    c.pyapi.incref(val)
    return val


@unbox(LoggingLoggerType)
def unbox_logging_logger(typ, obj, c):
    c.pyapi.incref(obj)
    return NativeValue(obj)


@lower_constant(LoggingLoggerType)
def lower_constant_logger(context, builder, ty, pyval):
    cbsi__ppjvw = context.get_python_api(builder)
    return cbsi__ppjvw.unserialize(cbsi__ppjvw.serialize_object(pyval))


gen_objmode_attr_overload(LoggingLoggerType, 'level', None, types.int64)
gen_objmode_attr_overload(LoggingLoggerType, 'name', None, 'unicode_type')
gen_objmode_attr_overload(LoggingLoggerType, 'propagate', None, types.boolean)
gen_objmode_attr_overload(LoggingLoggerType, 'disabled', None, types.boolean)
gen_objmode_attr_overload(LoggingLoggerType, 'parent', None,
    LoggingLoggerType())
gen_objmode_attr_overload(LoggingLoggerType, 'root', None,
    LoggingLoggerType(is_root=True))


@infer_getattr
class LoggingLoggerAttribute(AttributeTemplate):
    key = LoggingLoggerType

    def _resolve_helper(self, logger_typ, args, kws):
        kws = dict(kws)
        snzy__sulcc = ', '.join('e{}'.format(ncebo__ztf) for ncebo__ztf in
            range(len(args)))
        if snzy__sulcc:
            snzy__sulcc += ', '
        wnlq__bdn = ', '.join("{} = ''".format(utfv__aemn) for utfv__aemn in
            kws.keys())
        qck__fqjva = f'def format_stub(string, {snzy__sulcc} {wnlq__bdn}):\n'
        qck__fqjva += '    pass\n'
        gxkgt__vqdn = {}
        exec(qck__fqjva, {}, gxkgt__vqdn)
        iuauo__gfzg = gxkgt__vqdn['format_stub']
        ntq__xbqcq = numba.core.utils.pysignature(iuauo__gfzg)
        epmwf__lhzwr = (logger_typ,) + args + tuple(kws.values())
        return signature(logger_typ, epmwf__lhzwr).replace(pysig=ntq__xbqcq)
    func_names = ('debug', 'warning', 'warn', 'info', 'error', 'exception',
        'critical', 'log', 'setLevel')
    for pqlmu__zwo in ('logging.Logger', 'logging.RootLogger'):
        for dlgjk__dro in func_names:
            qefqt__wdnz = f'@bound_function("{pqlmu__zwo}.{dlgjk__dro}")\n'
            qefqt__wdnz += (
                f'def resolve_{dlgjk__dro}(self, logger_typ, args, kws):\n')
            qefqt__wdnz += (
                '    return self._resolve_helper(logger_typ, args, kws)')
            exec(qefqt__wdnz)


logging_logger_unsupported_attrs = {'filters', 'handlers', 'manager'}
logging_logger_unsupported_methods = {'addHandler', 'callHandlers', 'fatal',
    'findCaller', 'getChild', 'getEffectiveLevel', 'handle', 'hasHandlers',
    'isEnabledFor', 'makeRecord', 'removeHandler'}


def _install_logging_logger_unsupported_objects():
    for hpnqu__cexfb in logging_logger_unsupported_attrs:
        galol__crt = 'logging.Logger.' + hpnqu__cexfb
        overload_attribute(LoggingLoggerType, hpnqu__cexfb)(
            create_unsupported_overload(galol__crt))
    for msvx__jkbfo in logging_logger_unsupported_methods:
        galol__crt = 'logging.Logger.' + msvx__jkbfo
        overload_method(LoggingLoggerType, msvx__jkbfo)(
            create_unsupported_overload(galol__crt))


_install_logging_logger_unsupported_objects()

==> bodo-2022.6-cp38-cp38-macosx_10_15_x86_64.whl: bodo/libs/logging_ext.py <==
"""
JIT support for Python's logging module
"""
import logging
import numba
from numba.core import types
from numba.core.imputils import lower_constant
from numba.core.typing.templates import bound_function
from numba.core.typing.templates import AttributeTemplate, infer_getattr, signature
from numba.extending import NativeValue, box, models, overload_attribute, overload_method, register_model, typeof_impl, unbox
from bodo.utils.typing import create_unsupported_overload, gen_objmode_attr_overload


class LoggingLoggerType(types.Type):

    def __init__(self, is_root=False):
        self.is_root = is_root
        super(LoggingLoggerType, self).__init__(name=
            f'LoggingLoggerType(is_root={is_root})')


@typeof_impl.register(logging.RootLogger)
@typeof_impl.register(logging.Logger)
def typeof_logging(val, c):
    if isinstance(val, logging.RootLogger):
        return LoggingLoggerType(is_root=True)
    else:
        return LoggingLoggerType(is_root=False)


register_model(LoggingLoggerType)(models.OpaqueModel)


@box(LoggingLoggerType)
def box_logging_logger(typ, val, c):
    c.pyapi.incref(val)
    return val


@unbox(LoggingLoggerType)
def unbox_logging_logger(typ, obj, c):
    c.pyapi.incref(obj)
    return NativeValue(obj)


@lower_constant(LoggingLoggerType)
def lower_constant_logger(context, builder, ty, pyval):
    drbm__ztio = context.get_python_api(builder)
    return drbm__ztio.unserialize(drbm__ztio.serialize_object(pyval))


gen_objmode_attr_overload(LoggingLoggerType, 'level', None, types.int64)
gen_objmode_attr_overload(LoggingLoggerType, 'name', None, 'unicode_type')
gen_objmode_attr_overload(LoggingLoggerType, 'propagate', None, types.boolean)
gen_objmode_attr_overload(LoggingLoggerType, 'disabled', None, types.boolean)
gen_objmode_attr_overload(LoggingLoggerType, 'parent', None,
    LoggingLoggerType())
gen_objmode_attr_overload(LoggingLoggerType, 'root', None,
    LoggingLoggerType(is_root=True))


@infer_getattr
class LoggingLoggerAttribute(AttributeTemplate):
    key = LoggingLoggerType

    def _resolve_helper(self, logger_typ, args, kws):
        kws = dict(kws)
        ajall__gznmd = ', '.join('e{}'.format(iwh__xfk) for iwh__xfk in
            range(len(args)))
        if ajall__gznmd:
            ajall__gznmd += ', '
        mrj__amafa = ', '.join("{} = ''".format(ycej__ixr) for ycej__ixr in
            kws.keys())
        vzck__vqzen = (
            f'def format_stub(string, {ajall__gznmd} {mrj__amafa}):\n')
        vzck__vqzen += '    pass\n'
        rxz__ixv = {}
        exec(vzck__vqzen, {}, rxz__ixv)
        damh__qbra = rxz__ixv['format_stub']
        tbryk__trcp = numba.core.utils.pysignature(damh__qbra)
        vui__mosjk = (logger_typ,) + args + tuple(kws.values())
        return signature(logger_typ, vui__mosjk).replace(pysig=tbryk__trcp)
    func_names = ('debug', 'warning', 'warn', 'info', 'error', 'exception',
        'critical', 'log', 'setLevel')
    for acv__ityy in ('logging.Logger', 'logging.RootLogger'):
        for kxk__ofmj in func_names:
            rge__ble = f'@bound_function("{acv__ityy}.{kxk__ofmj}")\n'
            rge__ble += (
                f'def resolve_{kxk__ofmj}(self, logger_typ, args, kws):\n')
            rge__ble += (
                '    return self._resolve_helper(logger_typ, args, kws)')
            exec(rge__ble)


logging_logger_unsupported_attrs = {'filters', 'handlers', 'manager'}
logging_logger_unsupported_methods = {'addHandler', 'callHandlers', 'fatal',
    'findCaller', 'getChild', 'getEffectiveLevel', 'handle', 'hasHandlers',
    'isEnabledFor', 'makeRecord', 'removeHandler'}


def _install_logging_logger_unsupported_objects():
    for cbymh__aerfq in logging_logger_unsupported_attrs:
        jpb__frwr = 'logging.Logger.' + cbymh__aerfq
        overload_attribute(LoggingLoggerType, cbymh__aerfq)(
            create_unsupported_overload(jpb__frwr))
    for snh__hgj in logging_logger_unsupported_methods:
        jpb__frwr = 'logging.Logger.' + snh__hgj
        overload_method(LoggingLoggerType, snh__hgj)(
            create_unsupported_overload(jpb__frwr))


_install_logging_logger_unsupported_objects()
